@@ -1,8 +1,6 @@
 package Future::HTTP;
 use strict;
-use Filter::signatures;
-no warnings 'experimental::signatures';
-use feature 'signatures';
+use experimental 'signatures';
 
 =head1 NAME
 
@@ -55,7 +53,7 @@ but has not materialized yet.
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 our @loops;
 push @loops, (
@@ -226,7 +224,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2016-2023 by Max Maischein C<corion@cpan.org>.
+Copyright 2016-2024 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
