@@ -1,10 +1,8 @@
 package Future::HTTP::Handler;
 use Moo::Role;
-use Filter::signatures;
-no warnings 'experimental::signatures';
-use feature 'signatures';
+use experimental 'signatures';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =head1 NAME
 
