@@ -3,11 +3,9 @@ use strict;
 use Future;
 use HTTP::Tiny::Paranoid 0.07; # 0.04 had spurious CPAN tester failures
 use Moo 2; # or Moo::Lax if you can't have Moo v2
-use Filter::signatures;
-no warnings 'experimental::signatures';
-use feature 'signatures';
+use experimental 'signatures';
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 extends 'Future::HTTP::Tiny';
 
@@ -155,7 +153,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2016-2023 by Max Maischein C<corion@cpan.org>.
+Copyright 2016-2024 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
